@@ -40,6 +40,7 @@ future::plan("sequential")
 fold <- future.apply:::fold
 hpaste <- future.apply:::hpaste
 mdebug <- future.apply:::mdebug
+mdebugf <- future.apply:::mdebugf
 import_from <- future.apply:::import_from
 get_random_seed <- future.apply:::get_random_seed
 set_random_seed <- future.apply:::set_random_seed
@@ -60,8 +61,7 @@ supportedStrategies <- function(cores = 1L, excl = c("multiprocess", "cluster"),
   strategies <- future:::supportedStrategies(...)
   strategies <- setdiff(strategies, excl)
   if (cores > 1) {
-    strategies <- setdiff(strategies,
-                          c("sequential", "uniprocess", "eager", "lazy"))
+    strategies <- setdiff(strategies, c("sequential", "uniprocess"))
   }
   strategies
 }
